@@ -9,12 +9,8 @@
 #ifndef REMOTEVIEW_H
 #define REMOTEVIEW_H
 
-#ifndef QTONLY
 #include "krdccore_export.h"
 #include <KWallet>
-#else
-#define KRDCCORE_EXPORT
-#endif
 
 #include <QClipboard>
 #include <QMap>
@@ -25,7 +21,7 @@
 #include "shortcutinhibition_p.h"
 #endif
 
-#if defined(LIBSSH_FOUND) && !defined(QTONLY)
+#if defined(LIBSSH_FOUND)
 #define USE_SSH_TUNNEL
 #include "sshtunnelthread.h"
 #endif
@@ -36,6 +32,7 @@ struct ModifierKey {
 };
 
 class HostPreferences;
+class KModifierKeyInfo;
 
 /**
  * Generic widget that displays a remote framebuffer.
@@ -263,12 +260,23 @@ public:
      */
     virtual QPixmap takeScreenshot();
 
-#ifndef QTONLY
+    /**
+     * @return status of the caps lock key
+     */
+    bool isCapsLockEnabled();
+    /**
+     * @return status of the num lock key
+     */
+    bool isNumLockEnabled();
+    /**
+     * @return status of the scroll lock key
+     */
+    bool isScrollLockEnabled();
+
     /**
      * Returns the current host preferences of this view.
      */
     virtual HostPreferences *hostPreferences() = 0;
-#endif
 
     /**
      * Returns the current status of the connection.
@@ -421,6 +429,7 @@ protected:
     virtual void handleWheelEvent(QWheelEvent *event) = 0;
     virtual void handleMouseEvent(QMouseEvent *event) = 0;
     virtual void handleLocalClipboardChanged(const QMimeData *data) = 0;
+    virtual void handleDevicePixelRatioChange() { };
     /**
      * The status of the remote view.
      */
@@ -456,11 +465,12 @@ protected:
     qreal m_factor;
     QClipboard *m_clipboard;
     QMap<int, ModifierKey> m_modifiers;
+    KModifierKeyInfo *m_modifierKeyInfo;
+
 #ifdef HAVE_WAYLAND
     std::unique_ptr<ShortcutInhibition> m_inhibition;
 #endif
 
-#ifndef QTONLY
     QString readWalletPassword(bool fromUserNameOnly = false);
     void saveWalletPassword(const QString &password, bool fromUserNameOnly = false);
     void deleteWalletPassword(bool fromUserNameOnly = false);
@@ -468,7 +478,6 @@ protected:
     void saveWalletPasswordForKey(const QString &key, const QString &password);
     void deleteWalletPasswordForKey(const QString &key);
     KWallet::Wallet *m_wallet;
-#endif
 
     LocalCursorState m_localCursorState;
 
